@@ -53,7 +53,7 @@
 #include "aclMath/aclVectorOfElementsDef.h"
 #include "aclMath/aclMatrixOfElements.h"
 
-#include<string>
+#include <string>
 
 using namespace std;
 using namespace asl;
@@ -522,11 +522,11 @@ namespace acl
 
 	template <typename T> void copy(MemBlock & source, MemBlock & destination)
 	{
-		if (source.size() == destination.getSize())
+		if (source.getSize() == destination.getSize())
 		{
 			if (source.getQueue().get() == destination.getQueue().get())
 			{
-				// \todoIgal swap buffers???
+				// \todo swap buffers???
 			}
 			else
 			{
